documentation_extras
==================================================
**Module**: :mod:`espressodb.documentation.templatetags.documentation_extras`


.. automodule:: espressodb.documentation.templatetags.documentation_extras
    :members:
    :special-members:
